aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/pet_control/pet_starfield.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/titanic/pet_control/pet_starfield.h')
-rw-r--r--engines/titanic/pet_control/pet_starfield.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/titanic/pet_control/pet_starfield.h b/engines/titanic/pet_control/pet_starfield.h
index ec96fb93ef..01dddfd564 100644
--- a/engines/titanic/pet_control/pet_starfield.h
+++ b/engines/titanic/pet_control/pet_starfield.h
@@ -105,9 +105,9 @@ public:
virtual void save(SimpleFile *file, int indent);
/**
* Sets the offsets for each of the buttons
*/
- void setButtons(int val1, int val2);
+ void setButtons(int matchIndex, bool isMarkerClose);
/**
* Sets whether the player has the galactic reference material
@@ -105,9 +105,9 @@ public:
virtual void save(SimpleFile *file, int indent);
/**
- * Sets the offsets for each of the buttons
+ * Sets the display for the marker buttons
*/